@@ -2149,7 +2149,7 @@ e_book_set_default_source (ESource *source, GError **error)
 	source = e_source_list_peek_source_by_uid (sources, uid);
 	if (!source) {
 		g_set_error (error, E_BOOK_ERROR, E_BOOK_ERROR_NO_SUCH_SOURCE,
-			     _("%s: there was no source for uid `%s' stored in gconf."), "e_book_set_default_source", uid);
+			     _("%s: there was no source for UID '%s' stored in GConf."), "e_book_set_default_source", uid);
 		g_object_unref (sources);
 		return FALSE;
 	}
@@ -2523,27 +2523,6 @@ unwrap_gerror (GError *error, GError **client_error)
 	return FALSE;
 }
 
-static gboolean
-strcaseequal_no_underscore (const gchar *str1, const gchar *str2)
-{
-	gint i, j;
-
-	if (!str1 || !str2)
-		return FALSE;
-
-	for (i = 0, j = 0; str1[i] && str2[j]; i++, j++) {
-		while (str1[i] == '_' && str1[i + 1])
-			i++;
-		while (str2[j] == '_' && str2[j + 1])
-			j++;
-
-		if (g_ascii_tolower (str1[i]) != g_ascii_tolower (str2[j]))
-			return FALSE;
-	}
-
-	return !str1[i] && !str2[j];
-}
-
 /**
  * If the GError is a remote error, extract the EBookStatus embedded inside.
  * Otherwise return CORBA_EXCEPTION (I know this is DBus...).
@@ -2590,8 +2569,7 @@ get_status_from_error (GError *error)
 		name = dbus_g_error_get_name (error);
 
 		for (i = 0; i < G_N_ELEMENTS (errors); i++) {
-			if (g_ascii_strcasecmp (errors[i].name, name) == 0 ||
-			    strcaseequal_no_underscore (errors[i].name, name))
+			if (g_ascii_strcasecmp (errors[i].name, name) == 0)
 				return errors[i].err_code;
 		}
 
