@@ -63,13 +63,18 @@ static const gchar *e_cal_match_location(const gchar *location)
 
 /**
  * e_cal_match_tzid:
- * matches a TZID against the system timezone definitions
- * and returns the matching TZID, or NULL if none found
+ * @tzid: a timezone ID
+ *
+ * Matches @tzid against the system timezone definitions
+ * and returns the matching TZID, or %NULL if none found
+ *
+ * Since: 2.24
  */
-const gchar *e_cal_match_tzid(const gchar *tzid)
+const gchar *
+e_cal_match_tzid(const gchar *tzid)
 {
     const gchar *location;
-    const gchar *systzid;
+    const gchar *systzid = NULL;
     gsize len = strlen(tzid);
     gssize eostr;
 
@@ -95,7 +100,7 @@ const gchar *e_cal_match_tzid(const gchar *tzid)
             systzid = e_cal_match_tzid(strippedtzid);
             g_free(strippedtzid);
             if (systzid) {
-                return systzid;
+                goto done;
             }
         }
     }
@@ -113,13 +118,28 @@ const gchar *e_cal_match_tzid(const gchar *tzid)
                                        location + 1 :
                                        location);
         if (systzid) {
-            return systzid;
+            goto done;
         }
     }
 
     /* TODO: lookup table for Exchange TZIDs */
 
-    return NULL;
+ done:
+    if (systzid && !strcmp(systzid, "UTC")) {
+        /**
+         * UTC is special: it doesn't have a real VTIMEZONE in
+         * EDS. Matching some pseudo VTTIMEZONE with UTC in the TZID
+         * to our internal UTC "timezone" breaks
+         * e_cal_check_timezones() (it patches the event to use
+         * TZID=UTC, which cannot be exported correctly later on) and
+         * e_cal_get_timezone() (triggers an assert).
+         *
+         * So better avoid matching against it...
+         */
+        return NULL;
+    } else {
+        return systzid;
+    }
 }
 
 static void patch_tzids(icalcomponent *subcomp,
@@ -226,15 +246,18 @@ static void addsystemtz(gpointer key,
  * the TZID. All items referencing the renamed TZID are adapted
  * accordingly.
  *
- * Return value: TRUE if successful, FALSE otherwise.
+ * Returns: TRUE if successful, FALSE otherwise.
+ *
+ * Since: 2.24
  */
-gboolean e_cal_check_timezones(icalcomponent *comp,
-                               GList *comps,
-                               icaltimezone *(*tzlookup)(const gchar *tzid,
-                                                         gconstpointer custom,
-                                                         GError **error),
-                               gconstpointer custom,
-                               GError **error)
+gboolean
+e_cal_check_timezones (icalcomponent *comp,
+                       GList *comps,
+                       icaltimezone *(*tzlookup)(const gchar *tzid,
+                                                 gconstpointer custom,
+                                                 GError **error),
+                       gconstpointer custom,
+                       GError **error)
 {
     gboolean success = TRUE;
     icalcomponent *subcomp = NULL;
@@ -434,10 +457,13 @@ gboolean e_cal_check_timezones(icalcomponent *comp,
  *
  * An implementation of the tzlookup callback which clients
  * can use. Calls #e_cal_get_timezone.
+ *
+ * Since: 2.24
  */
-icaltimezone *e_cal_tzlookup_ecal(const gchar *tzid,
-                                  gconstpointer custom,
-                                  GError **error)
+icaltimezone *
+e_cal_tzlookup_ecal (const gchar *tzid,
+                     gconstpointer custom,
+                     GError **error)
 {
     ECal *ecal = (ECal *)custom;
     icaltimezone *zone = NULL;
@@ -468,10 +494,13 @@ icaltimezone *e_cal_tzlookup_ecal(const gchar *tzid,
  * An implementation of the tzlookup callback which backends
  * like the file backend can use. Searches for the timezone
  * in the component list.
+ *
+ * Since: 2.24
  */
-icaltimezone *e_cal_tzlookup_icomp(const gchar *tzid,
-                                   gconstpointer custom,
-                                   GError **error)
+icaltimezone *
+e_cal_tzlookup_icomp (const gchar *tzid,
+                      gconstpointer custom,
+                      GError **error)
 {
     icalcomponent *icomp = (icalcomponent *)custom;
 
