@@ -1,10 +1,9 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* Evolution calendar - generic backend class
  *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2001 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Rodrigo Moya <rodrigo@ximian.com>    
+ * Authors: Rodrigo Moya <rodrigo@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -17,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_CAL_BACKEND_UTIL_H
@@ -31,8 +30,12 @@ G_BEGIN_DECLS
  * Functions for accessing mail configuration
  */
 
-gboolean e_cal_backend_mail_account_get_default (char **address, char **name);
-gboolean e_cal_backend_mail_account_is_valid (char *user, char **name);
+gboolean e_cal_backend_mail_account_get_default (gchar **address, gchar **name);
+gboolean e_cal_backend_mail_account_is_valid (gchar *user, gchar **name);
+
+const gchar *e_cal_backend_status_to_string (GNOME_Evolution_Calendar_CallStatus status);
+
+gboolean e_cal_backend_user_declined (icalcomponent *icalcomp);
 
 G_END_DECLS
 
