@@ -33,17 +33,15 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
-#include <glib.h>
+#include "camel-file-utils.h"
+#include "camel-operation.h"
+#include "camel-url.h"
 
 #ifdef G_OS_WIN32
 #include <winsock2.h>
 #define EWOULDBLOCK EAGAIN
 #endif
 
-#include "camel-file-utils.h"
-#include "camel-operation.h"
-#include "camel-url.h"
-
 #define IO_TIMEOUT (60*4)
 
 /**
@@ -53,7 +51,7 @@
  *
  * Utility function to save an uint32 to a file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_uint32 (FILE *out, guint32 value)
@@ -77,7 +75,7 @@ camel_file_util_encode_uint32 (FILE *out, guint32 value)
  *
  * Retrieve an encoded uint32 from a file.
  *
- * Return value: %0 on success, %-1 on error.  @*dest will contain the
+ * Returns: %0 on success, %-1 on error.  @*dest will contain the
  * decoded value.
  **/
 gint
@@ -108,7 +106,7 @@ camel_file_util_decode_uint32 (FILE *in, guint32 *dest)
  * Encode a gint32, performing no compression, but converting
  * to network order.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_fixed_int32 (FILE *out, gint32 value)
@@ -128,7 +126,7 @@ camel_file_util_encode_fixed_int32 (FILE *out, gint32 value)
  *
  * Retrieve a gint32.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_decode_fixed_int32 (FILE *in, gint32 *dest)
@@ -181,7 +179,7 @@ camel_file_util_decode_##type(FILE *in, type *dest)	\
  *
  * Encode a time_t value to the file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(time_t)
 
@@ -192,7 +190,7 @@ CFU_ENCODE_T(time_t)
  *
  * Decode a time_t value.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_DECODE_T(time_t)
 
@@ -203,7 +201,7 @@ CFU_DECODE_T(time_t)
  *
  * Encode an off_t type.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(off_t)
 
@@ -214,7 +212,7 @@ CFU_ENCODE_T(off_t)
  *
  * Decode an off_t type.
  *
- * Return value: %0 on success, %-1 on failure.
+ * Returns: %0 on success, %-1 on failure.
  **/
 CFU_DECODE_T(off_t)
 
@@ -225,7 +223,7 @@ CFU_DECODE_T(off_t)
  *
  * Encode an gsize type.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(gsize)
 
@@ -236,7 +234,7 @@ CFU_ENCODE_T(gsize)
  *
  * Decode an gsize type.
  *
- * Return value: %0 on success, %-1 on failure.
+ * Returns: %0 on success, %-1 on failure.
  **/
 CFU_DECODE_T(gsize)
 
@@ -247,7 +245,7 @@ CFU_DECODE_T(gsize)
  *
  * Encode a normal string and save it in the output file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_string (FILE *out, const gchar *str)
@@ -274,7 +272,7 @@ camel_file_util_encode_string (FILE *out, const gchar *str)
  *
  * Decode a normal string from the input file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_decode_string (FILE *in, gchar **str)
@@ -315,7 +313,7 @@ camel_file_util_decode_string (FILE *in, gchar **str)
  * Unlike @camel_file_util_encode_string, it pads the
  * @str with "NULL" bytes, if @len is > strlen(str)
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_encode_fixed_string (FILE *out, const gchar *str, gsize len)
@@ -347,7 +345,7 @@ camel_file_util_encode_fixed_string (FILE *out, const gchar *str, gsize len)
  *
  * Decode a normal string from the input file.
  *
- * Return value: %0 on success, %-1 on error.
+ * Returns: %0 on success, %-1 on error.
  **/
 gint
 camel_file_util_decode_fixed_string (FILE *in, gchar **str, gsize len)
@@ -412,7 +410,9 @@ camel_file_util_safe_filename (const gchar *name)
  * be set appropriately.
  **/
 gssize
-camel_read (gint fd, gchar *buf, gsize n)
+camel_read (gint fd,
+            gchar *buf,
+            gsize n)
 {
 	gssize nread;
 	gint cancel_fd;
@@ -489,7 +489,9 @@ camel_read (gint fd, gchar *buf, gsize n)
  * be set appropriately.
  **/
 gssize
-camel_write (gint fd, const gchar *buf, gsize n)
+camel_write (gint fd,
+             const gchar *buf,
+             gsize n)
 {
 	gssize w, written = 0;
 	gint cancel_fd;
@@ -580,7 +582,9 @@ camel_write (gint fd, const gchar *buf, gsize n)
  * camel_read_socket() will retry the read until it gets something.
  **/
 gssize
-camel_read_socket (gint fd, gchar *buf, gsize n)
+camel_read_socket (gint fd,
+                   gchar *buf,
+                   gsize n)
 {
 #ifndef G_OS_WIN32
 	return camel_read (fd, buf, n);
@@ -650,7 +654,9 @@ camel_read_socket (gint fd, gchar *buf, gsize n)
  * be set appropriately.
  **/
 gssize
-camel_write_socket (gint fd, const gchar *buf, gsize n)
+camel_write_socket (gint fd,
+                    const gchar *buf,
+                    gsize n)
 {
 #ifndef G_OS_WIN32
 	return camel_write (fd, buf, n);
@@ -726,7 +732,7 @@ camel_write_socket (gint fd, const gchar *buf, gsize n)
  * basename of @filename, for instance used in a two-stage commit file
  * write.
  *
- * Return value: The new pathname.  It must be free'd with g_free().
+ * Returns: The new pathname.  It must be free'd with g_free().
  **/
 gchar *
 camel_file_util_savename(const gchar *filename)
@@ -750,20 +756,3 @@ camel_file_util_savename(const gchar *filename)
 
 	return retval;
 }
-
-/**
- * camel_mkdir:
- * @path: directory path to create
- * @mode: permissions
- *
- * Creates the directory path described in @path, creating any parent
- * directories as necessary.
- *
- * Returns 0 on success or -1 on fail. In the case of failure, errno
- * will be set appropriately.
- **/
-gint
-camel_mkdir (const gchar *path, mode_t mode)
-{
-	return g_mkdir_with_parents (path, mode);
-}
