@@ -37,7 +37,6 @@
 #include <string.h>
 #include <unistd.h>
 
-#include <glib.h>
 #include <glib/gi18n-lib.h>
 
 #ifndef G_OS_WIN32
@@ -65,41 +64,41 @@
 typedef struct {
 	CamelSession *session;
 	CamelFilterSearchGetMessageFunc get_message;
-	void *get_message_data;
+	gpointer get_message_data;
 	CamelMimeMessage *message;
 	CamelMessageInfo *info;
-	const char *source;
+	const gchar *source;
 	CamelException *ex;
 } FilterMessageSearch;
 
 /* ESExp callbacks */
-static ESExpResult *header_contains (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_matches (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_starts_with (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_ends_with (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_exists (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_soundex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_regex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_full_regex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *match_all (struct _ESExp *f, int argc, struct _ESExpTerm **argv, FilterMessageSearch *fms);
-static ESExpResult *body_contains (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *body_regex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *user_flag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *user_tag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *system_flag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *get_sent_date (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *get_received_date (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *get_current_date (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *header_source (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *get_size (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *pipe_message (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
-static ESExpResult *junk_test (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_contains (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_matches (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_starts_with (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_ends_with (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_exists (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_soundex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_regex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_full_regex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *match_all (struct _ESExp *f, gint argc, struct _ESExpTerm **argv, FilterMessageSearch *fms);
+static ESExpResult *body_contains (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *body_regex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *user_flag (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *user_tag (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *system_flag (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *get_sent_date (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *get_received_date (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *get_current_date (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *header_source (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *get_size (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *pipe_message (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
+static ESExpResult *junk_test (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms);
 
 /* builtin functions */
 static struct {
-	char *name;
+	const gchar *name;
 	ESExpFunc *func;
-	int type;		/* set to 1 if a function can perform shortcut evaluation, or
+	gint type;		/* set to 1 if a function can perform shortcut evaluation, or
 				   doesn't execute everything, 0 otherwise */
 } symbols[] = {
 	{ "match-all",          (ESExpFunc *) match_all,          1 },
@@ -125,37 +124,36 @@ static struct {
 	{ "junk-test",          (ESExpFunc *) junk_test,          0 },
 };
 
-
 static CamelMimeMessage *
 camel_filter_search_get_message (FilterMessageSearch *fms, struct _ESExp *sexp)
 {
 	if (fms->message)
 		return fms->message;
-	
+
 	fms->message = fms->get_message (fms->get_message_data, fms->ex);
-	
+
 	if (fms->message == NULL)
 		e_sexp_fatal_error (sexp, _("Failed to retrieve message"));
-	
+
 	return fms->message;
 }
 
 static ESExpResult *
-check_header (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms, camel_search_match_t how)
+check_header (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms, camel_search_match_t how)
 {
 	gboolean matched = FALSE;
 	ESExpResult *r;
-	int i;
-	
+	gint i;
+
 	if (argc > 1 && argv[0]->type == ESEXP_RES_STRING) {
-		char *name = argv[0]->value.string;
+		gchar *name = argv[0]->value.string;
 
 		/* shortcut: a match for "" against any header always matches */
 		for (i=1; i<argc && !matched; i++)
 			matched = argv[i]->type == ESEXP_RES_STRING && argv[i]->value.string[0] == 0;
 
 		if (g_ascii_strcasecmp(name, "x-camel-mlist") == 0) {
-			const char *list = camel_message_info_mlist(fms->info);
+			const gchar *list = camel_message_info_mlist(fms->info);
 
 			if (list) {
 				for (i=1; i<argc && !matched; i++) {
@@ -165,25 +163,27 @@ check_header (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMess
 			}
 		} else {
 			CamelMimeMessage *message;
+			CamelMimePart *mime_part;
 			struct _camel_header_raw *header;
-			const char *charset = NULL;
+			const gchar *charset = NULL;
 			camel_search_t type = CAMEL_SEARCH_TYPE_ENCODED;
 			CamelContentType *ct;
 
 			message = camel_filter_search_get_message (fms, f);
+			mime_part = CAMEL_MIME_PART (message);
 
 			/* FIXME: what about Resent-To, Resent-Cc and Resent-From? */
 			if (g_ascii_strcasecmp("to", name) == 0 || g_ascii_strcasecmp("cc", name) == 0 || g_ascii_strcasecmp("from", name) == 0)
 				type = CAMEL_SEARCH_TYPE_ADDRESS_ENCODED;
 			else if (message) {
-				ct = camel_mime_part_get_content_type (CAMEL_MIME_PART (message));
+				ct = camel_mime_part_get_content_type (mime_part);
 				if (ct) {
 					charset = camel_content_type_param (ct, "charset");
 					charset = camel_iconv_charset_name (charset);
 				}
 			}
 
-			for (header = ((CamelMimePart *)message)->headers; header && !matched; header = header->next) {
+			for (header = mime_part->headers; header && !matched; header = header->next) {
 				if (!g_ascii_strcasecmp(header->name, name)) {
 					for (i=1; i<argc && !matched; i++) {
 						if (argv[i]->type == ESEXP_RES_STRING)
@@ -193,95 +193,96 @@ check_header (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMess
 			}
 		}
 	}
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.bool = matched;
-	
+	r->value.boolean = matched;
+
 	return r;
 }
 
 static ESExpResult *
-header_contains (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_contains (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	return check_header (f, argc, argv, fms, CAMEL_SEARCH_MATCH_CONTAINS);
 }
 
-
 static ESExpResult *
-header_matches (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_matches (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	return check_header (f, argc, argv, fms, CAMEL_SEARCH_MATCH_EXACT);
 }
 
 static ESExpResult *
-header_starts_with (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_starts_with (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	return check_header (f, argc, argv, fms, CAMEL_SEARCH_MATCH_STARTS);
 }
 
 static ESExpResult *
-header_ends_with (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_ends_with (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	return check_header (f, argc, argv, fms, CAMEL_SEARCH_MATCH_ENDS);
 }
 
 static ESExpResult *
-header_soundex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_soundex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	return check_header (f, argc, argv, fms, CAMEL_SEARCH_MATCH_SOUNDEX);
 }
 
 static ESExpResult *
-header_exists (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_exists (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	CamelMimeMessage *message;
 	gboolean matched = FALSE;
 	ESExpResult *r;
-	int i;
-	
+	gint i;
+
 	message = camel_filter_search_get_message (fms, f);
-	
+
 	for (i = 0; i < argc && !matched; i++) {
 		if (argv[i]->type == ESEXP_RES_STRING)
 			matched = camel_medium_get_header (CAMEL_MEDIUM (message), argv[i]->value.string) != NULL;
 	}
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.bool = matched;
-	
+	r->value.boolean = matched;
+
 	return r;
 }
 
 static ESExpResult *
-header_regex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_regex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r = e_sexp_result_new (f, ESEXP_RES_BOOL);
 	CamelMimeMessage *message;
 	regex_t pattern;
-	const char *contents;
-	
+	const gchar *contents;
+
 	message = camel_filter_search_get_message (fms, f);
-	
+
 	if (argc > 1 && argv[0]->type == ESEXP_RES_STRING
 	    && (contents = camel_medium_get_header (CAMEL_MEDIUM (message), argv[0]->value.string))
 	    && camel_search_build_match_regex(&pattern, CAMEL_SEARCH_MATCH_REGEX|CAMEL_SEARCH_MATCH_ICASE, argc-1, argv+1, fms->ex) == 0) {
-		r->value.bool = regexec (&pattern, contents, 0, NULL, 0) == 0;
+		r->value.boolean = regexec (&pattern, contents, 0, NULL, 0) == 0;
 		regfree (&pattern);
 	} else
-		r->value.bool = FALSE;
-	
+		r->value.boolean = FALSE;
+
 	return r;
 }
 
 static gchar *
 get_full_header (CamelMimeMessage *message)
 {
-	CamelMimePart *mp = CAMEL_MIME_PART (message);
+	CamelMimePart *mime_part;
 	GString *str = g_string_new ("");
-	char   *ret;
+	gchar   *ret;
 	struct _camel_header_raw *h;
-	
-	for (h = mp->headers; h; h = h->next) {
+
+	mime_part = CAMEL_MIME_PART (message);
+
+	for (h = mime_part->headers; h; h = h->next) {
 		if (h->value != NULL) {
 			g_string_append (str, h->name);
 			if (isspace (h->value[0]))
@@ -292,91 +293,91 @@ get_full_header (CamelMimeMessage *message)
 			g_string_append_c(str, '\n');
 		}
 	}
-	
+
 	ret = str->str;
 	g_string_free (str, FALSE);
-	
+
 	return ret;
 }
 
 static ESExpResult *
-header_full_regex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_full_regex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r = e_sexp_result_new (f, ESEXP_RES_BOOL);
 	CamelMimeMessage *message;
 	regex_t pattern;
-	char *contents;
-	
+	gchar *contents;
+
 	if (camel_search_build_match_regex(&pattern, CAMEL_SEARCH_MATCH_REGEX|CAMEL_SEARCH_MATCH_ICASE|CAMEL_SEARCH_MATCH_NEWLINE,
 					   argc, argv, fms->ex) == 0) {
 		message = camel_filter_search_get_message (fms, f);
 		contents = get_full_header (message);
-		r->value.bool = regexec (&pattern, contents, 0, NULL, 0) == 0;
+		r->value.boolean = regexec (&pattern, contents, 0, NULL, 0) == 0;
 		g_free (contents);
 		regfree (&pattern);
 	} else
-		r->value.bool = FALSE;
-	
+		r->value.boolean = FALSE;
+
 	return r;
 }
 
 static ESExpResult *
-match_all (struct _ESExp *f, int argc, struct _ESExpTerm **argv, FilterMessageSearch *fms)
+match_all (struct _ESExp *f, gint argc, struct _ESExpTerm **argv, FilterMessageSearch *fms)
 {
 	/* match-all: when dealing with single messages is a no-op */
 	ESExpResult *r;
-	
+
 	if (argc > 0)
 		return e_sexp_term_eval (f, argv[0]);
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.bool = TRUE;
-	
+	r->value.boolean = TRUE;
+
 	return r;
 }
 
 static ESExpResult *
-body_contains (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+body_contains (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r = e_sexp_result_new (f, ESEXP_RES_BOOL);
 	CamelMimeMessage *message;
 	regex_t pattern;
-	
+
 	if (camel_search_build_match_regex (&pattern, CAMEL_SEARCH_MATCH_ICASE, argc, argv, fms->ex) == 0) {
 		message = camel_filter_search_get_message (fms, f);
-		r->value.bool = camel_search_message_body_contains ((CamelDataWrapper *) message, &pattern);
+		r->value.boolean = camel_search_message_body_contains ((CamelDataWrapper *) message, &pattern);
 		regfree (&pattern);
 	} else
-		r->value.bool = FALSE;
-	
+		r->value.boolean = FALSE;
+
 	return r;
 }
 
 static ESExpResult *
-body_regex (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+body_regex (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r = e_sexp_result_new(f, ESEXP_RES_BOOL);
 	CamelMimeMessage *message;
 	regex_t pattern;
-	
+
 	if (camel_search_build_match_regex(&pattern, CAMEL_SEARCH_MATCH_ICASE|CAMEL_SEARCH_MATCH_REGEX|CAMEL_SEARCH_MATCH_NEWLINE,
 					   argc, argv, fms->ex) == 0) {
 		message = camel_filter_search_get_message (fms, f);
-		r->value.bool = camel_search_message_body_contains ((CamelDataWrapper *) message, &pattern);
+		r->value.boolean = camel_search_message_body_contains ((CamelDataWrapper *) message, &pattern);
 		regfree (&pattern);
 	} else
-		r->value.bool = FALSE;
-	
+		r->value.boolean = FALSE;
+
 	return r;
 }
 
 static ESExpResult *
-user_flag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+user_flag (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
 	gboolean truth = FALSE;
-	int i;
-	
+	gint i;
+
 	/* performs an OR of all words */
 	for (i = 0; i < argc && !truth; i++) {
 		if (argv[i]->type == ESEXP_RES_STRING
@@ -385,88 +386,88 @@ user_flag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessage
 			break;
 		}
 	}
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.bool = truth;
-	
+	r->value.boolean = truth;
+
 	return r;
 }
 
 static ESExpResult *
-system_flag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+system_flag (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
-	
+
 	if (argc != 1 || argv[0]->type != ESEXP_RES_STRING)
 		e_sexp_fatal_error(f, _("Invalid arguments to (system-flag)"));
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_BOOL);
-	r->value.bool = camel_system_flag_get (camel_message_info_flags(fms->info), argv[0]->value.string);
-	
+	r->value.boolean = camel_system_flag_get (camel_message_info_flags(fms->info), argv[0]->value.string);
+
 	return r;
 }
 
 static ESExpResult *
-user_tag (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+user_tag (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
-	const char *tag;
+	const gchar *tag;
 
 	if (argc != 1 || argv[0]->type != ESEXP_RES_STRING)
 		e_sexp_fatal_error(f, _("Invalid arguments to (user-tag)"));
-	
+
 	tag = camel_message_info_user_tag(fms->info, argv[0]->value.string);
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_STRING);
 	r->value.string = g_strdup (tag ? tag : "");
-	
+
 	return r;
 }
 
 static ESExpResult *
-get_sent_date (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+get_sent_date (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	CamelMimeMessage *message;
 	ESExpResult *r;
-	
+
 	message = camel_filter_search_get_message (fms, f);
 	r = e_sexp_result_new (f, ESEXP_RES_INT);
 	r->value.number = camel_mime_message_get_date (message, NULL);
-	
+
 	return r;
 }
 
 static ESExpResult *
-get_received_date (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+get_received_date (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	CamelMimeMessage *message;
 	ESExpResult *r;
-	
+
 	message = camel_filter_search_get_message (fms, f);
 	r = e_sexp_result_new (f, ESEXP_RES_INT);
 	r->value.number = camel_mime_message_get_date_received (message, NULL);
-	
+
 	return r;
 }
 
 static ESExpResult *
-get_current_date (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+get_current_date (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
-	
+
 	r = e_sexp_result_new (f, ESEXP_RES_INT);
 	r->value.number = time (NULL);
-	
+
 	return r;
 }
 
 static ESExpResult *
-header_source (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+header_source (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	CamelMimeMessage *message;
 	ESExpResult *r;
-	const char *src;
-	int truth = FALSE, i;
+	const gchar *src;
+	gint truth = FALSE, i;
 	CamelProvider *provider;
 	CamelURL *uria, *urib;
 
@@ -494,17 +495,17 @@ header_source (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMes
 	}
 
 	r = e_sexp_result_new(f, ESEXP_RES_BOOL);
-	r->value.bool = truth;
-	
+	r->value.boolean = truth;
+
 	return r;
 }
 
 /* remember, the size comparisons are done at Kbytes */
 static ESExpResult *
-get_size (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+get_size (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
-	
+
 	r = e_sexp_result_new(f, ESEXP_RES_INT);
 	r->value.number = camel_message_info_size(fms->info) / 1024;
 
@@ -539,28 +540,28 @@ child_watch (GPid     pid,
 	g_main_loop_quit (child_watch_data->loop);
 }
 
-static int
-run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+static gint
+run_command (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	CamelMimeMessage *message;
 	CamelStream *stream;
-	int i;
-	int pipe_to_child;
+	gint i;
+	gint pipe_to_child;
 	GPid child_pid;
 	GError *error = NULL;
 	GPtrArray *args;
 	child_watch_data_t child_watch_data;
 	GSource *source;
 	GMainContext *context;
-	
+
 	if (argc < 1 || argv[0]->value.string[0] == '\0')
 		return 0;
-	
+
 	args = g_ptr_array_new ();
 	for (i = 0; i < argc; i++)
 		g_ptr_array_add (args, argv[i]->value.string);
 	g_ptr_array_add (args, NULL);
-	
+
 	if (!g_spawn_async_with_pipes (NULL,
 				       (gchar **) args->pdata,
 				       NULL,
@@ -577,22 +578,24 @@ run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessa
 				       &error)) {
 		g_ptr_array_free (args, TRUE);
 
-		camel_exception_setv (fms->ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Failed to create create child process '%s': %s"),
-				      argv[0]->value.string, error->message);
+		camel_exception_setv (
+			fms->ex, CAMEL_EXCEPTION_SYSTEM,
+			_("Failed to create child process '%s': %s"),
+			argv[0]->value.string, error->message);
 		g_error_free (error);
 		return -1;
 	}
-	
+
 	g_ptr_array_free (args, TRUE);
-	
+
 	message = camel_filter_search_get_message (fms, f);
-	
+
 	stream = camel_stream_fs_new_with_fd (pipe_to_child);
-	camel_data_wrapper_write_to_stream (CAMEL_DATA_WRAPPER (message), stream);
+	camel_data_wrapper_write_to_stream (
+		CAMEL_DATA_WRAPPER (message), stream);
 	camel_stream_flush (stream);
-	camel_object_unref (stream);
-	
+	g_object_unref (stream);
+
 	context = g_main_context_new ();
 	child_watch_data.loop = g_main_loop_new (context, FALSE);
 	g_main_context_unref (context);
@@ -616,11 +619,11 @@ run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessa
 }
 
 static ESExpResult *
-pipe_message (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+pipe_message (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
-	int retval, i;
-	
+	gint retval, i;
+
 	/* make sure all args are strings */
 	for (i = 0; i < argc; i++) {
 		if (argv[i]->type != ESEXP_RES_STRING) {
@@ -628,23 +631,23 @@ pipe_message (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMess
 			goto done;
 		}
 	}
-	
+
 	retval = run_command (f, argc, argv, fms);
-	
+
  done:
 	r = e_sexp_result_new (f, ESEXP_RES_INT);
 	r->value.number = retval;
-	
+
 	return r;
 }
 
 static ESExpResult *
-junk_test (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
+junk_test (struct _ESExp *f, gint argc, struct _ESExpResult **argv, FilterMessageSearch *fms)
 {
 	ESExpResult *r;
 	gboolean retval = FALSE;
 	CamelMessageInfo *info = fms->info;
-	
+
 	d(printf("doing junk test for message from '%s'\n", camel_message_info_from (fms->info)));
 	if (fms->session->junk_plugin != NULL && (camel_message_info_flags (info) & (CAMEL_MESSAGE_JUNK | CAMEL_MESSAGE_NOTJUNK)) == 0) {
 		const GHashTable *ht = camel_session_get_junk_headers (fms->session);
@@ -652,11 +655,11 @@ junk_test (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessage
 
 		while (node && !retval) {
 			if (node->name) {
-				char *value = (char *) g_hash_table_lookup ((GHashTable *) ht, node->name);
+				gchar *value = (gchar *) g_hash_table_lookup ((GHashTable *) ht, node->name);
 				d(printf("JunkCheckMatch: %s %s %s\n", node->name, node->value, value));
 				if (value)
 					retval = camel_strstrcase(node->value, value) != NULL;
-		
+
 			}
 			node = node->next;
 		}
@@ -698,19 +701,20 @@ junk_test (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessage
  * @expression:
  * @ex:
  *
- * Returns one of CAMEL_SEARCH_MATCHED, CAMEL_SEARCH_NOMATCH, or CAMEL_SEARCH_ERROR.
+ * Returns: one of CAMEL_SEARCH_MATCHED, CAMEL_SEARCH_NOMATCH, or
+ * CAMEL_SEARCH_ERROR.
  **/
-int
+gint
 camel_filter_search_match (CamelSession *session,
-			   CamelFilterSearchGetMessageFunc get_message, void *data,
-			   CamelMessageInfo *info, const char *source,
-			   const char *expression, CamelException *ex)
+			   CamelFilterSearchGetMessageFunc get_message, gpointer data,
+			   CamelMessageInfo *info, const gchar *source,
+			   const gchar *expression, CamelException *ex)
 {
 	FilterMessageSearch fms;
 	ESExp *sexp;
 	ESExpResult *result;
 	gboolean retval;
-	int i;
+	gint i;
 
 	fms.session = session;
 	fms.get_message = get_message;
@@ -719,51 +723,54 @@ camel_filter_search_match (CamelSession *session,
 	fms.info = info;
 	fms.source = source;
 	fms.ex = ex;
-	
+
 	sexp = e_sexp_new ();
-	
-	for (i = 0; i < sizeof (symbols) / sizeof (symbols[0]); i++) {
+
+	for (i = 0; i < G_N_ELEMENTS (symbols); i++) {
 		if (symbols[i].type == 1)
 			e_sexp_add_ifunction (sexp, 0, symbols[i].name, (ESExpIFunc *)symbols[i].func, &fms);
 		else
 			e_sexp_add_function (sexp, 0, symbols[i].name, symbols[i].func, &fms);
 	}
-	
+
 	e_sexp_input_text (sexp, expression, strlen (expression));
 	if (e_sexp_parse (sexp) == -1) {
 		if (!camel_exception_is_set (ex))
-			/* A filter search is a search through your filters, ie. your filters is the corpus being searched thru. */
-			camel_exception_setv (ex, 1, _("Error executing filter search: %s: %s"),
-					      e_sexp_error (sexp), expression);
+			/* A filter search is a search through your filters,
+			 * ie. your filters is the corpus being searched thru. */
+			camel_exception_setv (
+				ex, 1, _("Error executing filter search: %s: %s"),
+				e_sexp_error (sexp), expression);
 		goto error;
 	}
-	
+
 	result = e_sexp_eval (sexp);
 	if (result == NULL) {
 		if (!camel_exception_is_set (ex))
-			camel_exception_setv (ex, 1, _("Error executing filter search: %s: %s"),
-					      e_sexp_error (sexp), expression);
+			camel_exception_setv (
+				ex, 1, _("Error executing filter search: %s: %s"),
+				e_sexp_error (sexp), expression);
 		goto error;
 	}
-	
+
 	if (result->type == ESEXP_RES_BOOL)
-		retval = result->value.bool ? CAMEL_SEARCH_MATCHED : CAMEL_SEARCH_NOMATCH;
+		retval = result->value.boolean ? CAMEL_SEARCH_MATCHED : CAMEL_SEARCH_NOMATCH;
 	else
 		retval = CAMEL_SEARCH_NOMATCH;
-	
+
 	e_sexp_result_free (sexp, result);
 	e_sexp_unref (sexp);
-	
+
 	if (fms.message)
-		camel_object_unref (fms.message);
-	
+		g_object_unref (fms.message);
+
 	return retval;
-	
+
  error:
 	if (fms.message)
-		camel_object_unref (fms.message);
-	
+		g_object_unref (fms.message);
+
 	e_sexp_unref (sexp);
-	
+
 	return CAMEL_SEARCH_ERROR;
 }
