@@ -29,23 +29,13 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <glib.h>
-
 #include "camel-html-parser.h"
 
 /* if defined, must also compile in dump_tag() below somewhere */
 #define d(x)
 
-static void camel_html_parser_class_init (CamelHTMLParserClass *klass);
-static void camel_html_parser_init       (CamelObject *o);
-static void camel_html_parser_finalize   (CamelObject *o);
-
-static CamelObjectClass *camel_html_parser_parent;
-
 /* Parser definitions, see below object code for details */
 
-typedef struct _CamelHTMLParserPrivate CamelHTMLParserPrivate;
-
 struct _CamelHTMLParserPrivate {
 	gchar *inbuf,
 		*inptr,
@@ -63,53 +53,41 @@ struct _CamelHTMLParserPrivate {
 	gint quote;
 };
 
-static void tokenise_setup(void);
-static CamelHTMLParserPrivate *tokenise_init(void);
-static void tokenise_free(CamelHTMLParserPrivate *p);
-static gint tokenise_step(CamelHTMLParserPrivate *p, gchar **datap, gint *lenp);
+static void tokenize_setup(void);
+static CamelHTMLParserPrivate *tokenize_init(void);
+static void tokenize_free(CamelHTMLParserPrivate *p);
+static gint tokenize_step(CamelHTMLParserPrivate *p, gchar **datap, gint *lenp);
+
+G_DEFINE_TYPE (CamelHTMLParser, camel_html_parser, CAMEL_TYPE_OBJECT)
 
 /* ********************************************************************** */
 
-CamelType
-camel_html_parser_get_type (void)
+static void
+html_parser_finalize (GObject *object)
 {
-	static CamelType type = CAMEL_INVALID_TYPE;
+	CamelHTMLParser *parser = CAMEL_HTML_PARSER (object);
 
-	if (type == CAMEL_INVALID_TYPE) {
-		type = camel_type_register (camel_object_get_type (), "CamelHTMLParser",
-					    sizeof (CamelHTMLParser),
-					    sizeof (CamelHTMLParserClass),
-					    (CamelObjectClassInitFunc) camel_html_parser_class_init,
-					    NULL,
-					    (CamelObjectInitFunc) camel_html_parser_init,
-					    (CamelObjectFinalizeFunc) camel_html_parser_finalize);
-	}
+	tokenize_free (parser->priv);
 
-	return type;
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (camel_html_parser_parent_class)->finalize (object);
 }
 
 static void
-camel_html_parser_finalize(CamelObject *o)
+camel_html_parser_class_init (CamelHTMLParserClass *class)
 {
-	CamelHTMLParser *f = (CamelHTMLParser *)o;
+	GObjectClass *object_class;
 
-	tokenise_free(f->priv);
+	object_class = G_OBJECT_CLASS (class);
+	object_class->finalize = html_parser_finalize;
+
+	tokenize_setup();
 }
 
 static void
-camel_html_parser_init       (CamelObject *o)
+camel_html_parser_init (CamelHTMLParser *parser)
 {
-	CamelHTMLParser *f = (CamelHTMLParser *)o;
-
-	f->priv = tokenise_init();
-}
-
-static void
-camel_html_parser_class_init (CamelHTMLParserClass *klass)
-{
-	camel_html_parser_parent = CAMEL_OBJECT_CLASS (camel_type_get_global_classfuncs (camel_object_get_type ()));
-
-	tokenise_setup();
+	parser->priv = tokenize_init();
 }
 
 /**
@@ -122,8 +100,7 @@ camel_html_parser_class_init (CamelHTMLParserClass *klass)
 CamelHTMLParser *
 camel_html_parser_new (void)
 {
-	CamelHTMLParser *new = CAMEL_HTML_PARSER ( camel_object_new (camel_html_parser_get_type ()));
-	return new;
+	return g_object_new (CAMEL_TYPE_HTML_PARSER, NULL);
 }
 
 void camel_html_parser_set_data(CamelHTMLParser *hp, const gchar *start, gint len, gint last)
@@ -137,7 +114,7 @@ void camel_html_parser_set_data(CamelHTMLParser *hp, const gchar *start, gint le
 
 camel_html_parser_t camel_html_parser_step(CamelHTMLParser *hp, const gchar **datap, gint *lenp)
 {
-	return tokenise_step(hp->priv, (gchar **)datap, lenp);
+	return tokenize_step(hp->priv, (gchar **)datap, lenp);
 }
 
 const gchar *camel_html_parser_left(CamelHTMLParser *hp, gint *lenp)
@@ -460,7 +437,7 @@ static struct {
 static GHashTable *entities;
 
 /* this cannot be called in a thread context */
-static void tokenise_setup(void)
+static void tokenize_setup(void)
 {
 	gint i;
 
@@ -472,7 +449,7 @@ static void tokenise_setup(void)
 	}
 }
 
-static CamelHTMLParserPrivate *tokenise_init(void)
+static CamelHTMLParserPrivate *tokenize_init(void)
 {
 	CamelHTMLParserPrivate *p;
 
@@ -487,12 +464,12 @@ static CamelHTMLParserPrivate *tokenise_init(void)
 	p->charset = NULL;
 
 	if (entities == NULL)
-		tokenise_setup();
+		tokenize_setup();
 
 	return p;
 }
 
-static void tokenise_free(CamelHTMLParserPrivate *p)
+static void tokenize_free(CamelHTMLParserPrivate *p)
 {
 	gint i;
 
@@ -536,7 +513,7 @@ static void dump_tag(CamelHTMLParserPrivate *p)
 }
 #endif
 
-static gint tokenise_step(CamelHTMLParserPrivate *p, gchar **datap, gint *lenp)
+static gint tokenize_step(CamelHTMLParserPrivate *p, gchar **datap, gint *lenp)
 {
 	gchar *in = p->inptr;
 	gchar *inend = p->inend;
