@@ -1,16 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-mime-part-utils : Utility for mime parsing and so on */
 
-
-/* 
+/*
  *
- * Author : 
+ * Author :
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -24,16 +23,23 @@
  * USA
  */
 
+#if !defined (__CAMEL_H_INSIDE__) && !defined (CAMEL_COMPILATION)
+#error "Only <camel/camel.h> can be included directly."
+#endif
+
 #ifndef CAMEL_MIME_PART_UTILS_H
-#define CAMEL_MIME_PART_UTILS_H 1
+#define CAMEL_MIME_PART_UTILS_H
 
 #include <camel/camel-mime-part.h>
 #include <camel/camel-folder-summary.h>
 
 G_BEGIN_DECLS
 
-void camel_mime_part_construct_content_from_parser(CamelMimePart *, CamelMimeParser *mp);
-gboolean camel_mime_message_build_preview (CamelMimePart *msg, CamelMessageInfo *info);
+void		camel_mime_part_construct_content_from_parser
+						(CamelMimePart *mime_part,
+						 CamelMimeParser *mp);
+gboolean	camel_mime_message_build_preview(CamelMimePart *mime_part,
+						 CamelMessageInfo *info);
 
 G_END_DECLS
 
