@@ -22,9 +22,12 @@
  * USA
  */
 
+#if !defined (__CAMEL_H_INSIDE__) && !defined (CAMEL_COMPILATION)
+#error "Only <camel/camel.h> can be included directly."
+#endif
 
 #ifndef CAMEL_MOVEMAIL_H
-#define CAMEL_MOVEMAIL_H 1
+#define CAMEL_MOVEMAIL_H
 
 #include <camel/camel-exception.h>
 
