@@ -378,7 +378,7 @@ gw_info_set_flags (CamelMessageInfo *info, guint32 flags, guint32 set)
 				CamelFolderChangeInfo *changes = camel_folder_change_info_new();
 
 				camel_folder_change_info_change_uid(changes, camel_message_info_uid(info));
-				camel_object_trigger_event(mi->summary->folder, "folder_changed", changes);
+				camel_folder_changed (mi->summary->folder, changes);
 				camel_folder_change_info_free(changes);
 				camel_folder_summary_touch(mi->summary);
 		}
@@ -451,7 +451,7 @@ groupwise_summary_clear (CamelFolderSummary *summary, gboolean uncache)
 	/*camel_folder_summary_save (summary);*/
 
 	if (camel_folder_change_info_changed (changes))
-		camel_object_trigger_event (summary->folder, "folder_changed", changes);
+		camel_folder_changed (summary->folder, changes);
 	camel_folder_change_info_free (changes);
 }
 
