@@ -34,24 +34,6 @@
 
 #include "e-data-server-util.h"
 
-/**
- * e_util_mkdir_hier:
- * @path: The directory hierarchy to create.
- * @mode: The permissions to use for the directories.
- *
- * Creates a directory hierarchy based on the string @path. If @path
- * is an absolute path, the directories will be created relative to
- * the root of the file system; otherwise, the directories will be
- * created relative to the current directory.
- *
- * Returns: 0 on success; -1 on failure.
- **/
-gint
-e_util_mkdir_hier (const gchar *path, mode_t mode)
-{
-	return g_mkdir_with_parents (path, mode);
-}
-
 /**
  * e_util_strstrcase:
  * @haystack: The string to search in.
@@ -287,6 +269,8 @@ e_util_utf8_strcasecmp (const gchar *s1, const gchar *s2)
  * e_util_utf8_remove_accents:
  *
  * Returns newly allocates string, copy of 'str', without accents.
+ *
+ * Since: 2.28
  **/
 gchar *
 e_util_utf8_remove_accents (const gchar *str)
@@ -414,23 +398,17 @@ e_utf8_strftime(gchar *s, gsize max, const gchar *fmt, const struct tm *tm)
 }
 
 /**
- * e_util_pthread_id:
- * @t: A pthread_t value
+ * e_util_gthread_id:
+ * @thread: A #GThread pointer
  *
  * Returns a 64-bit integer hopefully uniquely identifying the
- * thread. To be used in debugging output and logging only. To test
- * whether two pthread_t values refer to the same thread, use
- * pthread_equal().
+ * thread. To be used in debugging output and logging only.
+ * The returned value is just a cast of a pointer to the 64-bit integer.
  *
- * There is no guarantee that calling e_util_pthread_id() on one
+ * There is no guarantee that calling e_util_gthread_id() on one
  * thread first and later after that thread has dies on another won't
  * return the same integer.
  *
- * On some platforms it might even be that when called two times on
- * the same thread's pthread_t (with some pthread API calls inbetween)
- * we will return different values (this of course makes this function
- * rather useless on such platforms).
- *
  * On Linux and Win32, known to really return a unique id for each
  * thread existing at a certain time. No guarantee that ids won't be
  * reused after a thread has terminated, though.
@@ -438,35 +416,13 @@ e_utf8_strftime(gchar *s, gsize max, const gchar *fmt, const struct tm *tm)
  * Returns: A 64-bit integer.
  */
 guint64
-e_util_pthread_id (pthread_t t)
+e_util_gthread_id (GThread *thread)
 {
-#ifdef HAVE_GUINT64_CASTABLE_PTHREAD_T
-	/* We know that pthread_t is an integral type, or at least
-	 * castable to such without loss of precision.
-	 */
-	return (guint64) t;
-#elif defined (PTW32_VERSION)
-	/* pthreads-win32 implementation on Windows: Return the
-	 * pointer to the "actual object" (see pthread.h)
-	 */
 #if GLIB_SIZEOF_VOID_P == 8
 	/* 64-bit Windows */
-	return (guint64) t.p;
+	return (guint64) thread;
 #else
-	return (gint) t.p;
-#endif
-#else
-	/* Just return a checksum of the contents of the pthread_t */
-	{
-		guint64 retval = 0;
-		guchar *const tend = (guchar *) ((&t)+1);
-		guchar *tp = (guchar *) &t;
-
-		while (tp < tend)
-			retval = (retval << 5) - retval * *tp++;
-
-		return retval;
-	}
+	return (gint) thread;
 #endif
 }
 
@@ -522,7 +478,7 @@ static const gchar *cp_prefix;
 static const gchar *localedir;
 static const gchar *extensiondir;
 static const gchar *imagesdir;
-static const gchar *ui_gladedir;
+static const gchar *ui_uidir;
 
 static HMODULE hmodule;
 G_LOCK_DEFINE_STATIC (mutex);
@@ -602,7 +558,7 @@ setup (void)
 	localedir = replace_prefix (cp_prefix, EVOLUTION_LOCALEDIR);
 	extensiondir = replace_prefix (prefix, E_DATA_SERVER_EXTENSIONDIR);
 	imagesdir = replace_prefix (prefix, E_DATA_SERVER_IMAGESDIR);
-	ui_gladedir = replace_prefix (prefix, E_DATA_SERVER_UI_GLADEDIR);
+	ui_uidir = replace_prefix (prefix, E_DATA_SERVER_UI_UIDIR);
 
 	G_UNLOCK (mutex);
 }
@@ -627,7 +583,7 @@ e_util_get_##varbl (void)			\
 
 PRIVATE_GETTER(extensiondir)
 PRIVATE_GETTER(imagesdir)
-PRIVATE_GETTER(ui_gladedir)
+PRIVATE_GETTER(ui_uidir)
 
 PUBLIC_GETTER(prefix)
 PUBLIC_GETTER(cp_prefix)
