@@ -22,7 +22,6 @@
 #ifndef __E_DATA_SERVER_UTIL_H__
 #define __E_DATA_SERVER_UTIL_H__
 
-#include <pthread.h>
 #include <sys/types.h>
 #include <glib.h>
 
@@ -30,28 +29,23 @@ G_BEGIN_DECLS
 
 struct tm;
 
-#ifndef EDS_DISABLE_DEPRECATED
-G_GNUC_DEPRECATED
-int          e_util_mkdir_hier (const char *path, mode_t mode);
-#endif
-
 gchar       *e_util_strstrcase (const gchar *haystack, const gchar *needle);
 gchar       *e_util_unicode_get_utf8 (const gchar *text, gunichar *out);
 const gchar *e_util_utf8_strstrcase (const gchar *haystack, const gchar *needle);
 const gchar *e_util_utf8_strstrcasedecomp (const gchar *haystack, const gchar *needle);
-int	     e_util_utf8_strcasecmp (const gchar *s1, const gchar *s2);
-gchar       *e_util_utf8_remove_accents (const char *str);
-guint64      e_util_pthread_id (pthread_t t);
+gint	     e_util_utf8_strcasecmp (const gchar *s1, const gchar *s2);
+gchar       *e_util_utf8_remove_accents (const gchar *str);
+guint64      e_util_gthread_id (GThread *thread);
 void         e_filename_make_safe (gchar *string);
 
-size_t e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm);
-size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm);
+gsize e_utf8_strftime(gchar *s, gsize max, const gchar *fmt, const struct tm *tm);
+gsize e_strftime(gchar *s, gsize max, const gchar *fmt, const struct tm *tm);
 
 #ifdef G_OS_WIN32
-const char  *e_util_get_prefix (void) G_GNUC_CONST;
-const char  *e_util_get_cp_prefix (void) G_GNUC_CONST;
-const char  *e_util_get_localedir (void) G_GNUC_CONST;
-char        *e_util_replace_prefix (const char *configure_time_prefix, const char *runtime_prefix, const char *configure_time_path);
+const gchar  *e_util_get_prefix (void) G_GNUC_CONST;
+const gchar  *e_util_get_cp_prefix (void) G_GNUC_CONST;
+const gchar  *e_util_get_localedir (void) G_GNUC_CONST;
+gchar        *e_util_replace_prefix (const gchar *configure_time_prefix, const gchar *runtime_prefix, const gchar *configure_time_path);
 #endif
 
 G_END_DECLS
