@@ -73,6 +73,7 @@ struct _ENameSelectorDialogPrivate {
 
 	guint destination_index;
 	GSList *user_query_fields;
+	GtkSizeGroup *dest_label_size_group;
 };
 
 static void     search_changed                (ENameSelectorDialog *name_selector_dialog);
@@ -217,6 +218,11 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 	name_selector_dialog->priv->button_size_group =
 		gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
+	/* Create size group for destination labels */
+
+	name_selector_dialog->priv->dest_label_size_group =
+		gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
 	/* Set up contacts view */
 
 	column = gtk_tree_view_column_new ();
@@ -296,6 +302,9 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 	/* TODO: Remember last used source */
 
 	/* Set up dialog defaults */
+#if 0 // MEEGO - but we should consider for everyone
+	gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (name_selector_dialog->gui, "show-contacts-label")));
+#endif
 
 	gtk_dialog_add_buttons (GTK_DIALOG (name_selector_dialog),
 				GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
@@ -303,7 +312,7 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 
 	gtk_dialog_set_default_response (GTK_DIALOG (name_selector_dialog), GTK_RESPONSE_CLOSE);
 	gtk_window_set_modal            (GTK_WINDOW (name_selector_dialog), TRUE);
-	gtk_window_set_default_size     (GTK_WINDOW (name_selector_dialog), 472, 512);
+	gtk_window_set_default_size     (GTK_WINDOW (name_selector_dialog), 700, -1);
 	gtk_window_set_resizable        (GTK_WINDOW (name_selector_dialog), TRUE);
 	gtk_dialog_set_has_separator    (GTK_DIALOG (name_selector_dialog), FALSE);
 	gtk_container_set_border_width  (GTK_CONTAINER (name_selector_dialog), 4);
@@ -337,6 +346,7 @@ e_name_selector_dialog_finalize (GObject *object)
 
 	g_array_free (priv->sections, TRUE);
 	g_object_unref (priv->button_size_group);
+	g_object_unref (priv->dest_label_size_group);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_name_selector_dialog_parent_class)->finalize (object);
@@ -521,31 +531,96 @@ selection_changed (GtkTreeSelection *selection, SelData *data)
 	gtk_widget_set_sensitive (GTK_WIDGET (data->button), have_selection);
 }
 
+static GtkTreeView *
+make_tree_view_for_section (ENameSelectorDialog *name_selector_dialog, EDestinationStore *destination_store)
+{
+	GtkTreeView *tree_view;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer   *cell_renderer;
+
+	tree_view = GTK_TREE_VIEW (gtk_tree_view_new ());
+
+	column = gtk_tree_view_column_new ();
+	cell_renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new ());
+	gtk_tree_view_column_pack_start (column, cell_renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func (column, cell_renderer,
+						 (GtkTreeCellDataFunc) destination_column_formatter,
+						 name_selector_dialog, NULL);
+	gtk_tree_view_append_column (tree_view, column);
+	gtk_tree_view_set_headers_visible (tree_view, FALSE);
+	gtk_tree_view_set_model (tree_view, GTK_TREE_MODEL (destination_store));
+
+
+	return tree_view;
+}
+
+static void
+setup_section_button (ENameSelectorDialog *name_selector_dialog,
+		      GtkButton *button,
+		      double halign,
+		      const char *label_text,
+		      const char *icon_name,
+		      gboolean icon_before_label)
+{
+	GtkWidget *alignment;
+	GtkWidget *hbox;
+	GtkWidget *label;
+	GtkWidget *image;
+
+	gtk_size_group_add_widget (
+		name_selector_dialog->priv->button_size_group,
+		GTK_WIDGET (button));
+
+	alignment = gtk_alignment_new (halign, 0.5, 0.0, 0.0);
+	gtk_container_add (GTK_CONTAINER (button), GTK_WIDGET (alignment));
+
+	hbox = gtk_hbox_new (FALSE, 2);
+	gtk_widget_show (GTK_WIDGET (hbox));
+	gtk_container_add (GTK_CONTAINER (alignment), hbox);
+
+	label = gtk_label_new_with_mnemonic (label_text);
+	gtk_widget_show (label);
+
+	image = gtk_image_new_from_stock (icon_name, GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show (image);
+
+	if (icon_before_label) {
+		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	} else {
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	}
+}
+
 static gint
 add_section (ENameSelectorDialog *name_selector_dialog,
 	     const gchar *name, const gchar *pretty_name, EDestinationStore *destination_store)
 {
+	ENameSelectorDialogPrivate *priv;
 	Section            section;
-	GtkTreeViewColumn *column;
-	GtkCellRenderer   *cell_renderer;
-	GtkWidget	  *vbox, *hbox, *chbox;
-	GtkWidget	  *widget, *image, *label;
+	GtkWidget	  *vbox;
+	GtkWidget	  *alignment;
+	GtkWidget	  *scrollwin;
 	SelData		  *data;
 	GtkTreeSelection  *selection;
 	gchar		  *text;
+	GtkWidget         *hbox;
 
 	g_assert (name != NULL);
 	g_assert (pretty_name != NULL);
 	g_assert (E_IS_DESTINATION_STORE (destination_store));
 
+	priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
+
 	memset (&section, 0, sizeof (Section));
 
 	section.name = g_strdup (name);
-	section.section_box      = GTK_BOX (gtk_hbox_new (FALSE, 12));
+	section.section_box = GTK_BOX (gtk_hbox_new (FALSE, 12));
 	section.label = GTK_LABEL (gtk_label_new_with_mnemonic (pretty_name));
 	section.transfer_button  = GTK_BUTTON (gtk_button_new());
 	section.remove_button  = GTK_BUTTON (gtk_button_new());
-	section.destination_view = GTK_TREE_VIEW (gtk_tree_view_new ());
+	section.destination_view = make_tree_view_for_section (name_selector_dialog, destination_store);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (section.label), GTK_WIDGET (section.destination_view));
 
@@ -571,82 +646,44 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	g_signal_connect(section.remove_button, "clicked",
 				  G_CALLBACK (remove_button_clicked), data);
 
-	/* Set up view */
-	column = gtk_tree_view_column_new ();
-	cell_renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new ());
-	gtk_tree_view_column_pack_start (column, cell_renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func (column, cell_renderer,
-						 (GtkTreeCellDataFunc) destination_column_formatter,
-						 name_selector_dialog, NULL);
-	gtk_tree_view_append_column (section.destination_view, column);
-	gtk_tree_view_set_headers_visible (section.destination_view, FALSE);
-	gtk_tree_view_set_model (section.destination_view, GTK_TREE_MODEL (destination_store));
+	/* Alignment and vbox for the add/remove buttons */
 
-	vbox = gtk_vbox_new (FALSE, 0);
-	chbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (chbox), vbox, FALSE, FALSE, 12);
+	alignment = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
+	gtk_box_pack_start (section.section_box, alignment, FALSE, FALSE, 0);
 
-	/* Pack button (in an alignment) */
-	widget = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (widget), GTK_WIDGET (section.transfer_button));
-	gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 6);
-	gtk_size_group_add_widget (
-		name_selector_dialog->priv->button_size_group,
-		GTK_WIDGET (section.transfer_button));
+	vbox = gtk_vbox_new (TRUE, 6);
+	gtk_container_add (GTK_CONTAINER (alignment), vbox);
 
-	/*to get the image embedded in the button*/
-	widget = gtk_alignment_new (0.7, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (section.transfer_button), GTK_WIDGET (widget));
+	/* "Add" button */
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (section.transfer_button), FALSE, FALSE, 0);
+	setup_section_button (name_selector_dialog, section.transfer_button, 0.7, _("_Add"), "gtk-go-forward", FALSE);
 
-	hbox = gtk_hbox_new (FALSE, 2);
-	gtk_widget_show (GTK_WIDGET(hbox));
-	gtk_container_add (GTK_CONTAINER (widget), GTK_WIDGET(hbox));
-
-	label = gtk_label_new_with_mnemonic (_("_Add"));
-	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-	image = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-
-	widget = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (widget), GTK_WIDGET (section.remove_button));
-	gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 0);
-	gtk_size_group_add_widget (
-		name_selector_dialog->priv->button_size_group,
-		GTK_WIDGET (section.remove_button));
+	/* "Remove" button */
+	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (section.remove_button), FALSE, FALSE, 0);
+	setup_section_button (name_selector_dialog, section.remove_button, 0.5, _("_Remove"), "gtk-go-back", TRUE);
 	gtk_widget_set_sensitive (GTK_WIDGET (section.remove_button), FALSE);
 
-	widget = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (section.remove_button), widget);
+	/* Hbox for label and scrolled window.  This is a separate hbox, instead
+	 * of just using the section.section_box directly, as it has a different
+	 * spacing.
+	 */
 
-	hbox = gtk_hbox_new (FALSE, 2);
-	gtk_widget_show (hbox);
-	gtk_container_add (GTK_CONTAINER (widget), hbox);
+	hbox = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (section.section_box, hbox, TRUE, TRUE, 0);
 
-	image = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	/* Title label */
 
-	label = gtk_label_new_with_mnemonic (_("_Remove"));
-	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_size_group_add_widget (priv->dest_label_size_group, GTK_WIDGET (section.label));
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_misc_set_alignment (GTK_MISC (section.label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (section.label), FALSE, FALSE, 0);
 
-	widget = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (widget), GTK_WIDGET (section.label));
-	gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 0);
-
-	/* Pack view (in a scrolled window) */
-	widget = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_IN);
-	gtk_container_add (GTK_CONTAINER (widget), GTK_WIDGET (section.destination_view));
-	gtk_box_pack_start (GTK_BOX (chbox), widget, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), chbox, TRUE, TRUE, 0);
-	gtk_box_pack_start (section.section_box, vbox, TRUE, TRUE, 0);
+	/* Treeview in a scrolled window */
+	scrollwin = gtk_scrolled_window_new (NULL, NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), scrollwin, TRUE, TRUE, 0);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_IN);
+	gtk_container_add (GTK_CONTAINER (scrollwin), GTK_WIDGET (section.destination_view));
 
 	/*data for 'changed' callback*/
 	data = g_malloc0(sizeof(SelData));
@@ -664,12 +701,13 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	g_signal_connect_swapped (section.destination_view, "key-press-event",
 				  G_CALLBACK (destination_key_press), name_selector_dialog);
 
+	/* Done! */
+
 	gtk_widget_show_all (GTK_WIDGET (section.section_box));
 
 	/* Pack this section's box into the dialog */
-	gtk_box_pack_start (
-		name_selector_dialog->priv->destination_box,
-		GTK_WIDGET (section.section_box), TRUE, TRUE, 0);
+	gtk_box_pack_start (name_selector_dialog->priv->destination_box,
+			    GTK_WIDGET (section.section_box), TRUE, TRUE, 0);
 
 	g_array_append_val (name_selector_dialog->priv->sections, section);
 
